import tktk.base_enhance.ListFrame
import tktk.base_enhance.LogFrame
#pip install git+https://gitee.com/w-8/tktk.git

class ListFrame(tktk.base_enhance.ListFrame.ListFrame):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
class LogFrame(tktk.base_enhance.LogFrame.LogFrame):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)





from setuptools import setup,find_packages
setup(name='tktk',
      version='0.2',
      description='tkinter的增强控件,将tkinter的基础控件进行封装,给予更强大的控件功能,所有控件继承于LabelFrame进行封装,使用方法和普通控件没什么区别;',
      classifiers=[
        'Programming Language :: Python',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
    ],
      url='https://gitee.com/w-8/tktk',
      author='bili:凿寂',
      author_email='mdzzdyxc@163.com',
      license='MIT',
      packages=find_packages(),
      zip_safe=True
     )